TrackerCallback
===============

.. currentmodule:: pykeen.training.callbacks

.. autoclass:: TrackerCallback
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~TrackerCallback.post_epoch

   .. rubric:: Methods Documentation

   .. automethod:: post_epoch
